==> theremin_1.1.0-1.tar.gz: theremin-1.1.0/src/OptionsDialog.hpp <==
/* The MIT License:

Copyright (c) 2009 Ivan Gagis

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE. */

/* 
 * File:   OptionsDialog.hpp
 * Author: ivan
 *
 * Created on February 23, 2009, 4:10 PM
 */

#ifndef M_OptionsDialog_hpp
#define	M_OptionsDialog_hpp

#include <ting/types.hpp>

#include <gtkmm/dialog.h>
#include <gtkmm/radiobutton.h>
#include <gtkmm/box.h>
#include <gtkmm/frame.h>

class OptionsDialog : public Gtk::Dialog{
	Gtk::Frame octavesFrame;
	Gtk::VBox octavesBox;
	Gtk::RadioButton oneOctaveRadioButton;
	Gtk::RadioButton twoOctavesRadioButton;
	Gtk::RadioButton threeOctavesRadioButton;
public:
	OptionsDialog(Gtk::Window &parent);

	ting::uint GetNumOctaves()const;
	void SetNumOctaves(ting::uint num);
};

#endif//~once

==> theremin_1.2.0-1.tar.gz: theremin-1.2.0/src/OptionsDialog.hpp <==
/* The MIT License:

Copyright (c) 2009 Ivan Gagis

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE. */

/* 
 * File:   OptionsDialog.hpp
 * Author: ivan
 *
 * Created on February 23, 2009, 4:10 PM
 */

#ifndef M_OptionsDialog_hpp
#define	M_OptionsDialog_hpp

#include <ting/types.hpp>

#include <gtkmm/dialog.h>
#include <gtkmm/radiobutton.h>
#include <gtkmm/box.h>
#include <gtkmm/frame.h>

class OptionsDialog : public Gtk::Dialog{
	Gtk::HBox hBox;

	Gtk::Frame octavesFrame;
	Gtk::VBox octavesBox;
	Gtk::RadioButton oneOctaveRadioButton;
	Gtk::RadioButton twoOctavesRadioButton;
	Gtk::RadioButton threeOctavesRadioButton;

	Gtk::Frame timbreFrame;
	Gtk::VBox timbreBox;
	Gtk::RadioButton sinePlusADSRButton;
	Gtk::RadioButton pluckedStringButton;
public:
	OptionsDialog(Gtk::Window &parent);

	ting::uint GetNumOctaves()const;
	void SetNumOctaves(ting::uint num);

	enum E_Timbre{
		SINE_PLUS_ADSR,
		PLUCKED_STRING,
		
		UNKNOWN, //NOTE: UNKNOWN must be last timbre in the list!!!
		
		NUM_TIMBRES
	};

	static std::string TimbreTypeToName(E_Timbre timbre);
	static E_Timbre TimbreNameToType(std::string name);

	E_Timbre GetTimbre()const;
	void SetTimbre(E_Timbre timbre);
};

#endif//~once
